"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const nock_1 = __importDefault(require("nock"));
const ts_invariant_1 = require("ts-invariant");
const utils_1 = require("../../../utils");
const contact_1 = require("../contact");
const baseUrl = process.env.BASE_URL || 'https://api.tripletex.io/';
const sessionToken = process.env.SESSION_TOKEN || 'a-session-token';
describe('activity class', () => {
    let client;
    beforeEach(() => {
        client = new contact_1.TripletexContact({ baseUrl }, sessionToken);
    });
    it('should list contacts', async () => {
        (0, nock_1.default)('https://api.tripletex.io:443', { encodedQueryParams: true })
            .get('/v2/contact')
            .reply(200, {
            fullResultSize: 1,
            from: 0,
            count: 1,
            versionDigest: 'Checksum not yet supported for this endpoint',
            values: [
                {
                    "id": 9004148,
                    "version": 1,
                    "url": "tripletex.no/v2/contact/88885",
                    "firstName": "Fastprisavtale",
                    "lastName": "",
                    "displayName": "Fastprisavtale",
                    "email": "",
                    "phoneNumberMobileCountry": {
                        "id": 161,
                        "url": "tripletex.no/v2/country/161"
                    },
                    "phoneNumberMobile": "",
                    "phoneNumberWork": "",
                    "customer": null,
                    "department": {
                        "id": 88885,
                        "url": "tripletex.no/v2/department/88885"
                    },
                    "isInactive": false
                }
            ],
        });
        const entries = await client.list();
        (0, utils_1.parseRuntypeValidationError)(entries.error);
        (0, ts_invariant_1.invariant)(entries.success);
        expect(entries.body.values).toMatchInlineSnapshot(`
Array [
  Object {
    "customer": null,
    "department": Object {
      "id": 88885,
      "url": "tripletex.no/v2/department/88885",
    },
    "displayName": "Fastprisavtale",
    "email": "",
    "firstName": "Fastprisavtale",
    "id": 9004148,
    "isInactive": false,
    "lastName": "",
    "phoneNumberMobile": "",
    "phoneNumberMobileCountry": Object {
      "id": 161,
      "url": "tripletex.no/v2/country/161",
    },
    "phoneNumberWork": "",
    "url": "tripletex.no/v2/contact/88885",
    "version": 1,
  },
]
`);
    });
});
